@@ -1,7 +1,7 @@
 package Config::IOD;
 
-our $DATE = '2015-09-06'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2015-09-08'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
@@ -169,7 +169,7 @@ sub _read_string {
 }
 
 1;
-# ABSTRACT: Read and write IOD configuration files
+# ABSTRACT: Read and write IOD/INI configuration files
 
 __END__
 
@@ -179,11 +179,11 @@ __END__
 
 =head1 NAME
 
-Config::IOD - Read and write IOD configuration files
+Config::IOD - Read and write IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.20 of Config::IOD (from Perl distribution Config-IOD), released on 2015-09-06.
+This document describes version 0.21 of Config::IOD (from Perl distribution Config-IOD), released on 2015-09-08.
 
 =head1 SYNOPSIS
 
@@ -203,7 +203,8 @@ This document describes version 0.20 of Config::IOD (from Perl distribution Conf
      # enable_expr         => 0,
  );
 
-Read IOD document from a file or string, return L<Config::IOD::Document> object:
+Read IOD/INI document from a file or string, return L<Config::IOD::Document>
+object:
 
  my $doc = $iod->read_file("/path/to/some.iod");
  my $doc = $iod->read_string("...");
@@ -212,9 +213,11 @@ See Config::IOD::Document for methods available for C<$doc>.
 
 =head1 DESCRIPTION
 
-This module is a round-trip parser for L<IOD> configuration format. Round-trip
-means all whitespaces and comments are preserved, so you get byte-by-byte
-equivalence if you dump back the parsed document into string.
+This module is a round-trip parser for L<IOD> configuration format (IOD is an
+INI-like format with more precise specification, some extra features, and 99%
+compatible with typical INI format). Round-trip means all whitespaces and
+comments are preserved, so you get byte-by-byte equivalence if you dump back the
+parsed document into string.
 
 Aside from parsing, methods for modifying IOD documents (add/delete sections &
 keys, etc) are also provided.
@@ -371,7 +374,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Config-IOD>.
+Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
 
 =head1 BUGS
 
